**Example 1: 导出规则视角**



Input: 

```
tccli cwp ExportBaselineRuleDetectList --cli-unfold-argument  \
    --ExportAll 1
```

Output: 
```
{
    "Response": {
        "RequestId": "cbc912a7-c030-4a80-8d76-6e938a930fa1"
    }
}
```

